@@ -10,6 +10,7 @@ from qiime2.sdk import Artifact, Visualization
 from qiime2.metadata import (Metadata, MetadataColumn,
                              CategoricalMetadataColumn, NumericMetadataColumn)
 from qiime2.plugin import Citations
+from qiime2.core.cache import Cache, Pool
 from ._version import get_versions
 
 __version__ = get_versions()['version']
@@ -23,7 +24,8 @@ __citations__ = tuple(Citations.load('citations.bib', package='qiime2'))
 __website__ = 'https://qiime2.org'
 
 __all__ = ['Artifact', 'Visualization', 'Metadata', 'MetadataColumn',
-           'CategoricalMetadataColumn', 'NumericMetadataColumn']
+           'CategoricalMetadataColumn', 'NumericMetadataColumn', 'Cache',
+           'Pool']
 
 
 # Used by `jupyter serverextension enable`
