@@ -13,6 +13,7 @@ import distutils
 import tempfile
 import weakref
 
+from qiime2.core.util import set_permissions, USER_GROUP_RWX
 
 _ConcretePath = type(pathlib.Path())
 
@@ -47,7 +48,15 @@ class OwnedPath(_ConcretePath):
             # condition on `rename`, so fall back to copying.
             try:
                 return _ConcretePath.rename(self, other)
-            except FileExistsError:
+            except (FileExistsError, OSError) as e:
+                # OSError errno 18 is cross device link, if we have this error
+                # we can solve it by copying. If we have a different OSError we
+                # still want to explode. FileExistsErrors are apparently
+                # instances of OSError, so we also make sure we don't have one
+                # of them when we explode
+                if isinstance(e, OSError) and e.errno != 18 and \
+                        not isinstance(e, FileExistsError):
+                    raise e
                 copied = self._copy_dir_or_file(other)
                 self._destruct()
                 return copied
@@ -112,6 +121,7 @@ class InternalDirectory(_ConcretePath):
     def _destruct(cls, path):
         """DO NOT USE DIRECTLY, use `_destructor()` instead"""
         if os.path.exists(path):
+            set_permissions(path, None, USER_GROUP_RWX)
             shutil.rmtree(path)
 
     @classmethod
