@@ -29,6 +29,8 @@ from .format import (
     EchoDirectoryFormat,
     Cephalapod,
     CephalapodDirectoryFormat,
+    ImportableOnlyFormat,
+    ExportableOnlyFormat
 )
 
 from .type import (IntSequence1, IntSequence2, IntSequence3, Mapping, FourInts,
@@ -43,7 +45,7 @@ from .method import (concatenate_ints, split_ints, merge_mappings,
                      params_only_method, no_input_method, deprecated_method,
                      optional_artifacts_method, long_description_method,
                      docstring_order_method, variadic_input_method,
-                     unioned_primitives, type_match_list_and_set)
+                     unioned_primitives, type_match_list_and_set, union_inputs)
 from .visualizer import (most_common_viz, mapping_viz, params_only_viz,
                          no_input_viz)
 from .pipeline import (parameter_only_pipeline, typical_pipeline,
@@ -89,7 +91,8 @@ dummy_plugin.register_semantic_types(IntSequence1, IntSequence2, IntSequence3,
 dummy_plugin.register_formats(
     IntSequenceFormatV2, MappingFormat, IntSequenceV2DirectoryFormat,
     IntSequenceMultiFileDirectoryFormat, MappingDirectoryFormat,
-    EchoDirectoryFormat, EchoFormat, Cephalapod, CephalapodDirectoryFormat)
+    EchoDirectoryFormat, EchoFormat, Cephalapod, CephalapodDirectoryFormat,
+    ImportableOnlyFormat, ExportableOnlyFormat)
 
 dummy_plugin.register_formats(
     FourIntsDirectoryFormat, UnimportableDirectoryFormat, UnimportableFormat,
@@ -100,33 +103,76 @@ dummy_plugin.register_views(
     SingleIntFormat, RedundantSingleIntDirectoryFormat,
     citations=[citations['mayer2012walking']])
 
-dummy_plugin.register_semantic_type_to_format(
+
+# Create IntSequence1 import example usage example
+def is1_use(use):
+    def factory():
+        from qiime2.core.testing.format import IntSequenceFormat
+        from qiime2.plugin.util import transform
+        ff = transform([1, 2, 3], to_type=IntSequenceFormat)
+
+        ff.validate()
+        return ff
+
+    to_import = use.init_format('to_import', factory, ext='.hello')
+
+    use.import_from_format('ints',
+                           semantic_type='IntSequence1',
+                           variable=to_import,
+                           view_type='IntSequenceFormat')
+
+
+dummy_plugin.register_artifact_class(
     IntSequence1,
-    artifact_format=IntSequenceDirectoryFormat
+    directory_format=IntSequenceDirectoryFormat,
+    description="The first IntSequence",
+    examples={'IntSequence1 import example': is1_use}
 )
-dummy_plugin.register_semantic_type_to_format(
+
+
+# Create IntSequence2 import example usage example
+def is2_use(use):
+    def factory():
+        from qiime2.core.testing.format import IntSequenceFormatV2
+        from qiime2.plugin.util import transform
+        ff = transform([1, 2, 3], to_type=IntSequenceFormatV2)
+
+        ff.validate()
+        return ff
+
+    to_import = use.init_format('to_import', factory, ext='.hello')
+
+    use.import_from_format('ints',
+                           semantic_type='IntSequence2',
+                           variable=to_import,
+                           view_type='IntSequenceFormatV2')
+
+
+dummy_plugin.register_artifact_class(
     IntSequence2,
-    artifact_format=IntSequenceV2DirectoryFormat
+    directory_format=IntSequenceV2DirectoryFormat,
+    description="The second IntSequence",
+    examples={'IntSequence2 import example': is2_use}
 )
 dummy_plugin.register_semantic_type_to_format(
     IntSequence3,
-    artifact_format=IntSequenceMultiFileDirectoryFormat
+    directory_format=IntSequenceMultiFileDirectoryFormat
 )
 dummy_plugin.register_semantic_type_to_format(
     Mapping,
-    artifact_format=MappingDirectoryFormat
+    directory_format=MappingDirectoryFormat
 )
 dummy_plugin.register_semantic_type_to_format(
     FourInts,
-    artifact_format=FourIntsDirectoryFormat
+    directory_format=FourIntsDirectoryFormat
 )
 dummy_plugin.register_semantic_type_to_format(
     SingleInt,
-    artifact_format=RedundantSingleIntDirectoryFormat
+    directory_format=RedundantSingleIntDirectoryFormat
 )
 dummy_plugin.register_semantic_type_to_format(
     Kennel[Dog | Cat],
-    artifact_format=MappingDirectoryFormat
+    directory_format=MappingDirectoryFormat
 )
 
 dummy_plugin.register_semantic_type_to_format(
@@ -138,15 +184,15 @@ dummy_plugin.register_semantic_type_to_format(
     | Foo
     | Bar
     | Baz,
-    artifact_format=EchoDirectoryFormat)
+    directory_format=EchoDirectoryFormat)
 
 dummy_plugin.register_semantic_type_to_format(
     AscIntSequence,
-    artifact_format=IntSequenceDirectoryFormat)
+    directory_format=IntSequenceDirectoryFormat)
 
 dummy_plugin.register_semantic_type_to_format(
     Squid | Octopus | Cuttlefish,
-    artifact_format=CephalapodDirectoryFormat)
+    directory_format=CephalapodDirectoryFormat)
 
 # TODO add an optional parameter to this method when they are supported
 dummy_plugin.methods.register_function(
@@ -160,9 +206,9 @@ dummy_plugin.methods.register_function(
         'int1': Int,
         'int2': Int
     },
-    outputs=[
-        ('concatenated_ints', IntSequence1)
-    ],
+    outputs={
+        'concatenated_ints': IntSequence1
+    },
     name='Concatenate integers',
     description='This method concatenates integers into'
                 ' a single sequence in the order they are provided.',
@@ -182,10 +228,10 @@ dummy_plugin.methods.register_function(
         'ints': T
     },
     parameters={},
-    outputs=[
-        ('left', T),
-        ('right', T)
-    ],
+    outputs={
+        'left': T,
+        'right': T
+    },
     name='Split sequence of integers in half',
     description='This method splits a sequence of integers in half, returning '
                 'the two halves (left and right). If the input sequence\'s '
@@ -712,4 +758,25 @@ dummy_plugin.pipelines.register_function(
                  ' cleaned up the way it should be.')
 )
 
+dummy_plugin.methods.register_function(
+    function=union_inputs,
+    inputs={
+        'ints1': IntSequence1,
+        'ints2': IntSequence2,
+    },
+    parameters={},
+    outputs=[
+        ('ints', IntSequence1)
+    ],
+    name='Inputs with typing.Union',
+    input_descriptions={
+        'ints1': 'An int artifact',
+        'ints2': 'An int artifact'
+    },
+    output_descriptions={
+        'ints': '[0]',
+    },
+    description='This method accepts a list or dict as first input.'
+)
+
 import_module('qiime2.core.testing.mapped')
