@@ -25,7 +25,7 @@ class DummyMetadataColumn(MetadataColumn):
 
     @classmethod
     def _is_supported_dtype(cls, dtype):
-        return dtype == 'float' or dtype == 'int'
+        return dtype == 'float' or dtype == 'int' or dtype == 'int64'
 
     @classmethod
     def _normalize_(cls, series):
