@@ -92,7 +92,7 @@ class PluginManager:
         self._reverse_transformers = collections.defaultdict(dict)
         self.formats = {}
         self.views = {}
-        self.type_formats = []
+        self.artifact_classes = {}
         self._ff_to_sfdf = {}
         self.validators = {}
 
@@ -201,7 +201,17 @@ class PluginManager:
                 )
 
             self.formats[name] = record
-        self.type_formats.extend(plugin.type_formats)
+
+        for name, record in plugin.artifact_classes.items():
+            if name in self.artifact_classes:
+                raise NameError(
+                    "Duplicate artifact class registration (%r) defined in "
+                    "plugins %r and %r." %
+                    (name, record.plugin.name,
+                     self.artifact_classes[name].plugin.name)
+                )
+            else:
+                self.artifact_classes[name] = record
 
         for semantic_type, validation_object in plugin.validators.items():
             if semantic_type not in self.validators:
@@ -212,13 +222,12 @@ class PluginManager:
                 validation_object)
 
     def get_semantic_types(self):
-        types = {}
+        result = {}
 
         for plugin in self.plugins.values():
-            for type_record in plugin.types.values():
-                types[str(type_record.semantic_type)] = type_record
+            result.update(plugin.artifact_classes)
 
-        return types
+        return result
 
     # TODO: Should plugin loading be transactional? i.e. if there's
     # something wrong, the entire plugin fails to load any piece, like a
@@ -228,7 +237,7 @@ class PluginManager:
         """
         get_formats(self, *, filter=None, semantic_type=None)
 
-        filter : enum
+        filter : enum | "IMPORTABLE" | "EXPORTABLE"
             filter is an enum integer that will be used to determine user
             input to output specified formats
 
@@ -240,12 +249,17 @@ class PluginManager:
         the user and the semantic type. The return is a dictionary of filtered
         formats keyed on their string names.
         """
-        if filter is not None and not isinstance(filter, GetFormatFilters):
-            raise ValueError("The format filter provided: %s is not "
-                             "valid.", (filter))
+        filter_map = {"IMPORTABLE": GetFormatFilters.IMPORTABLE,
+                      "EXPORTABLE": GetFormatFilters.EXPORTABLE}
+        if filter is not None and not isinstance(filter, GetFormatFilters) \
+                and filter not in filter_map:
+            raise ValueError(
+                f"The provided format filter {filter} is not valid.")
+        if isinstance(filter, str):
+            filter = filter_map[filter]
 
         if semantic_type is None:
-            formats = set(f.format for f in self.type_formats)
+            formats = set(f.format for f in self.artifact_classes.values())
 
         else:
             formats = set()
@@ -254,9 +268,9 @@ class PluginManager:
                 semantic_type = parse_type(semantic_type, "semantic")
 
             if is_semantic_type(semantic_type):
-                for type_format in self.type_formats:
-                    if semantic_type <= type_format.type_expression:
-                        formats.add(type_format.format)
+                for artifact_class in self.artifact_classes.values():
+                    if semantic_type <= artifact_class.semantic_type:
+                        formats.add(artifact_class.format)
                         break
 
                 if not formats:
@@ -322,14 +336,28 @@ class PluginManager:
 
         return result_formats
 
+    @property
+    def type_formats(self):
+        # self.type_formats was replaced with self.artifact_classes - this
+        # property provides backward compatibility
+        return list(self.artifact_classes.values())
+
     @property
     def importable_formats(self):
-        """Return formats that are importable.
+        """Formats that are importable.
         A format is importable in a QIIME 2 deployment if it can be transformed
         into at least one of the canonical semantic type formats.
         """
         return self.get_formats(filter=GetFormatFilters.IMPORTABLE)
 
+    @property
+    def exportable_formats(self):
+        """Formats that are exportable.
+        A format is exportable in a QIIME 2 deployment if it can be transformed
+        from at least one of the canonical semantic type formats.
+        """
+        return self.get_formats(filter=GetFormatFilters.EXPORTABLE)
+
     @property
     def importable_types(self):
         """Return set of concrete semantic types that are importable.
@@ -344,15 +372,14 @@ class PluginManager:
                 "Must provide a semantic type via `semantic_type`, not %r" %
                 semantic_type)
 
-        dir_fmt = None
-        for type_format_record in self.type_formats:
-            if semantic_type <= type_format_record.type_expression:
-                dir_fmt = type_format_record.format
-                break
+        # TODO: ideally we could just lookup semantic_type in
+        # self.artifact_classes but properties get in the way. Is there a way
+        # to strip properties so this could be simplified to return
+        # self.artifact_classes[semantic_type] while catching a KeyError?
+        for artifact_class_record in self.artifact_classes.values():
+            if semantic_type <= artifact_class_record.semantic_type:
+                return artifact_class_record.format
 
-        if dir_fmt is None:
-            raise TypeError(
-                "Semantic type %r does not have a compatible directory format."
-                % semantic_type)
-
-        return dir_fmt
+        raise TypeError(
+            "Semantic type %r does not have a compatible directory format."
+            % semantic_type)
