@@ -534,6 +534,24 @@ class TestMethod(unittest.TestCase):
         self.assertEqual(result.left.view(list), [0, 42])
         self.assertEqual(result.right.view(list), [-2, 43, 6])
 
+    def test_async_with_typing_unions(self):
+        union_inputs = self.plugin.methods['union_inputs']
+
+        artifact1 = Artifact.import_data(IntSequence1, [0, 42, 43])
+        artifact2 = Artifact.import_data(IntSequence2, [99, -22])
+
+        future = union_inputs.asynchronous(artifact1, artifact2)
+
+        self.assertIsInstance(future, concurrent.futures.Future)
+        result = future.result()
+
+        self.assertIsInstance(result, tuple)
+        self.assertEqual(len(result), 1)
+
+        # Test the `Results` object.
+        self.assertIsInstance(result, Results)
+        self.assertEqual(result[0].view(list), [0])
+
     def test_docstring(self):
         merge_mappings = self.plugin.methods['merge_mappings']
         split_ints = self.plugin.methods['split_ints']
