@@ -10,7 +10,8 @@ import unittest
 
 import qiime2.plugin
 import qiime2.sdk
-from qiime2.plugin.plugin import SemanticTypeRecord, FormatRecord
+from qiime2.plugin.plugin import (SemanticTypeRecord, FormatRecord,
+                                  ArtifactClassRecord)
 from qiime2.sdk.plugin_manager import GetFormatFilters
 
 from qiime2.core.testing.type import (IntSequence1, IntSequence2, IntSequence3,
@@ -29,7 +30,9 @@ from qiime2.core.testing.format import (Cephalapod, IntSequenceDirectoryFormat,
                                         RedundantSingleIntDirectoryFormat,
                                         EchoFormat,
                                         EchoDirectoryFormat,
-                                        CephalapodDirectoryFormat)
+                                        CephalapodDirectoryFormat,
+                                        ImportableOnlyFormat,
+                                        ExportableOnlyFormat)
 
 from qiime2.core.testing.validator import (validator_example_null1,
                                            validate_ascending_seq,
@@ -37,6 +40,8 @@ from qiime2.core.testing.validator import (validator_example_null1,
 
 from qiime2.core.testing.util import get_dummy_plugin
 
+from qiime2.core.testing.plugin import is1_use, is2_use
+
 
 class TestPluginManager(unittest.TestCase):
     def setUp(self):
@@ -116,29 +121,57 @@ class TestPluginManager(unittest.TestCase):
         self.assertEqual(types, exp)
 
     def test_get_semantic_types(self):
-        types = self.pm.get_semantic_types()
+        artifact_classes = self.pm.get_semantic_types()
 
-        exp = {
-            'IntSequence1': SemanticTypeRecord(semantic_type=IntSequence1,
-                                               plugin=self.plugin),
-            'IntSequence2': SemanticTypeRecord(semantic_type=IntSequence2,
-                                               plugin=self.plugin),
-            'Mapping':      SemanticTypeRecord(semantic_type=Mapping,
-                                               plugin=self.plugin),
-            'FourInts':     SemanticTypeRecord(semantic_type=FourInts,
-                                               plugin=self.plugin),
-            'Kennel[Dog]':  SemanticTypeRecord(semantic_type=Kennel[Dog],
-                                               plugin=self.plugin),
-            'Kennel[Cat]':  SemanticTypeRecord(semantic_type=Kennel[Cat],
-                                               plugin=self.plugin),
-            'SingleInt':    SemanticTypeRecord(semantic_type=SingleInt,
-                                               plugin=self.plugin),
-        }
+        is1 = ArtifactClassRecord(
+            semantic_type=IntSequence1,
+            format=IntSequenceDirectoryFormat,
+            plugin=self.plugin,
+            description="The first IntSequence",
+            examples={'IntSequence1 import example': is1_use},
+            type_expression=IntSequence1)
+        is2 = ArtifactClassRecord(
+            semantic_type=IntSequence2,
+            format=IntSequenceV2DirectoryFormat,
+            plugin=self.plugin,
+            description="The second IntSequence",
+            examples={'IntSequence2 import example': is2_use},
+            type_expression=IntSequence2)
+        is3 = ArtifactClassRecord(semantic_type=IntSequence3,
+                                  format=IntSequenceMultiFileDirectoryFormat,
+                                  plugin=self.plugin,
+                                  description="",
+                                  examples={},
+                                  type_expression=IntSequence3)
 
-        self.assertLessEqual(exp.keys(), types.keys())
-        self.assertNotIn(Cat, types)
-        self.assertNotIn(Dog, types)
-        self.assertNotIn(Kennel, types)
+        kd = ArtifactClassRecord(semantic_type=Kennel[Dog],
+                                 format=MappingDirectoryFormat,
+                                 plugin=self.plugin,
+                                 description="",
+                                 examples={},
+                                 type_expression=Kennel[Dog])
+
+        kc = ArtifactClassRecord(semantic_type=Kennel[Cat],
+                                 format=MappingDirectoryFormat,
+                                 plugin=self.plugin,
+                                 description="",
+                                 examples={},
+                                 type_expression=Kennel[Cat])
+
+        self.assertLessEqual(
+            {str(e.semantic_type) for e in [is1, is2, is3, kd, kc]},
+            artifact_classes.keys())
+
+        self.assertEqual(is1, artifact_classes['IntSequence1'])
+        self.assertEqual(is2, artifact_classes['IntSequence2'])
+        self.assertEqual(is3, artifact_classes['IntSequence3'])
+
+        self.assertNotIn('Cat', artifact_classes)
+        self.assertNotIn('Dog', artifact_classes)
+        self.assertNotIn('Kennel', artifact_classes)
+
+        self.assertIn('Kennel[Dog]', artifact_classes)
+        self.assertIn('Kennel[Cat]', artifact_classes)
 
     # TODO: add tests for type/directory/transformer registrations
     def test_get_formats_no_type_or_filter(self):
@@ -178,6 +211,12 @@ class TestPluginManager(unittest.TestCase):
             'CephalapodDirectoryFormat':
                 FormatRecord(format=CephalapodDirectoryFormat,
                              plugin=self.plugin),
+            'ImportableOnlyFormat':
+                FormatRecord(format=ImportableOnlyFormat,
+                             plugin=self.plugin),
+            'ExportableOnlyFormat':
+                FormatRecord(format=ExportableOnlyFormat,
+                             plugin=self.plugin),
         }
 
         obs = self.pm.get_formats()
@@ -200,7 +239,13 @@ class TestPluginManager(unittest.TestCase):
                              plugin=self.plugin),
             'IntSequenceMultiFileDirectoryFormat':
                 FormatRecord(format=IntSequenceMultiFileDirectoryFormat,
-                             plugin=self.plugin)
+                             plugin=self.plugin),
+            'ImportableOnlyFormat':
+                FormatRecord(format=ImportableOnlyFormat,
+                             plugin=self.plugin),
+            'ExportableOnlyFormat':
+                FormatRecord(format=ExportableOnlyFormat,
+                             plugin=self.plugin),
         }
 
         obs = self.pm.get_formats(semantic_type='IntSequence1')
@@ -220,6 +265,9 @@ class TestPluginManager(unittest.TestCase):
                              plugin=self.plugin),
             'IntSequenceV2DirectoryFormat':
                 FormatRecord(format=IntSequenceV2DirectoryFormat,
+                             plugin=self.plugin),
+            'ExportableOnlyFormat':
+                FormatRecord(format=ExportableOnlyFormat,
                              plugin=self.plugin)
         }
 
@@ -238,6 +286,9 @@ class TestPluginManager(unittest.TestCase):
                              plugin=self.plugin),
             'IntSequenceMultiFileDirectoryFormat':
                 FormatRecord(format=IntSequenceMultiFileDirectoryFormat,
+                             plugin=self.plugin),
+            'ImportableOnlyFormat':
+                FormatRecord(format=ImportableOnlyFormat,
                              plugin=self.plugin)
         }
 
@@ -287,6 +338,24 @@ class TestPluginManager(unittest.TestCase):
 
         self.assertEqual(exp, obs)
 
+    def test_get_formats_DF_exportable_str(self):
+        exp = {
+            'IntSequenceFormat':
+                FormatRecord(format=IntSequenceFormat,
+                             plugin=self.plugin),
+            'IntSequenceDirectoryFormat':
+                FormatRecord(format=IntSequenceDirectoryFormat,
+                             plugin=self.plugin),
+            'IntSequenceMultiFileDirectoryFormat':
+                FormatRecord(format=IntSequenceMultiFileDirectoryFormat,
+                             plugin=self.plugin)
+        }
+
+        obs = self.pm.get_formats(filter="EXPORTABLE",
+                                  semantic_type=IntSequence3)
+
+        self.assertEqual(exp, obs)
+
     def test_get_formats_DF_IMPORTABLE(self):
         exp = {
             'IntSequenceFormatV2':
@@ -305,13 +374,59 @@ class TestPluginManager(unittest.TestCase):
 
         self.assertEqual(exp, obs)
 
+    def test_get_formats_DF_importable_str(self):
+        exp = {
+            'IntSequenceFormatV2':
+                FormatRecord(format=IntSequenceFormatV2,
+                             plugin=self.plugin),
+            'IntSequenceV2DirectoryFormat':
+                FormatRecord(format=IntSequenceV2DirectoryFormat,
+                             plugin=self.plugin),
+            'IntSequenceMultiFileDirectoryFormat':
+                FormatRecord(format=IntSequenceMultiFileDirectoryFormat,
+                             plugin=self.plugin)
+        }
+
+        obs = self.pm.get_formats(filter="IMPORTABLE",
+                                  semantic_type=IntSequence3)
+
+        self.assertEqual(exp, obs)
+
     def test_get_formats_invalid_type(self):
         with self.assertRaisesRegex(ValueError, "No formats associated"):
             self.pm.get_formats(semantic_type='Random[Frequency]')
 
     def test_get_formats_invalid_filter(self):
         with self.assertRaisesRegex(ValueError, "filter.*is not valid"):
-            self.pm.get_formats(filter="EXPORTABLE")
+            self.pm.get_formats(filter="xyz")
+
+    def test_importable_formats_property(self):
+        imp_f = self.pm.importable_formats
+        self.assertTrue(isinstance(imp_f, dict))
+        # spot check for a few formats that should be present
+        self.assertTrue('IntSequenceFormatV2' in imp_f)
+        self.assertTrue('CephalapodDirectoryFormat' in imp_f)
+        self.assertTrue('ImportableOnlyFormat' in imp_f)
+        # spot check one that shouldn't be here
+        self.assertFalse('ExportableOnlyFormat' in imp_f)
+
+    def test_exportable_formats_property(self):
+        exp_f = self.pm.exportable_formats
+        self.assertTrue(isinstance(exp_f, dict))
+        # spot check for a few formats that should be present
+        self.assertTrue('IntSequenceDirectoryFormat' in exp_f)
+        self.assertTrue('IntSequenceV2DirectoryFormat' in exp_f)
+        self.assertTrue('ExportableOnlyFormat' in exp_f)
+        # spot check one that shouldn't be here
+        self.assertFalse('ImportableOnlyFormat' in exp_f)
+
+    def test_deprecated_type_formats(self):
+        # PluginManager.type_formats was replaced with
+        # PluginManager.artifact_classes. For backward compatibility the
+        # PluginManager.type_formats property returns the plugin manager's
+        # artifact_classes
+        self.assertEqual(self.pm.type_formats,
+                         list(self.pm.artifact_classes.values()))
 
 
 if __name__ == '__main__':
